summaryrefslogtreecommitdiffstats
path: root/src/storage/phrase_index.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/storage/phrase_index.h')
-rw-r--r--src/storage/phrase_index.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/storage/phrase_index.h b/src/storage/phrase_index.h
index 3654369..6a14ff7 100644
--- a/src/storage/phrase_index.h
+++ b/src/storage/phrase_index.h
@@ -213,14 +213,15 @@ public:
/* out */ guint32 & freq);
/**
- * PhraseItem::append_pronunciation:
+ * PhraseItem::add_pronunciation:
* @keys: the pronunciation keys.
- * @freq: the frequency of the pronunciation.
+ * @delta: the delta of the frequency of the pronunciation.
+ * @returns: whether the add operation is successful.
*
* Append one pronunciation.
*
*/
- void append_pronunciation(ChewingKey * keys, guint32 freq);
+ bool add_pronunciation(ChewingKey * keys, guint32 delta);
/**
* PhraseItem::remove_nth_pronunciation:
@@ -213,14 +213,15 @@ public:
*
- * Append one pronunciation.
+ * Add one pronunciation.
*
*/